@@ -16,10 +16,10 @@ class Site(Site):
     description = SETUP_INFO['description']
     version = SETUP_INFO['version']
     url = SETUP_INFO['url']
+    project_model = 'tickets.Site'
 
-    demo_fixtures = ['std', 'minimal_ledger', 'demo', 'demo2', 'checksummaries']
-                     # 'linotickets',
-                     # 'tractickets', 'luc']
+    demo_fixtures = ['std', 'minimal_ledger', 'demo', 'demo2', 'demo_bookings',
+    'checksummaries']  # 'linotickets', 'tractickets', 'luc']
 
     # project_model = 'tickets.Project'
     # project_model = 'deploy.Milestone'
@@ -48,6 +48,7 @@ class Site(Site):
         # yield 'lino.modlib.extjs'
         # yield 'lino.modlib.bootstrap3'
         yield 'lino.modlib.gfks'
+        yield 'lino.modlib.help'
         # yield 'lino.modlib.system'
         # yield 'lino.modlib.users'
         yield 'lino_noi.lib.contacts'
@@ -59,7 +60,7 @@ class Site(Site):
         # yield 'lino_noi.lib.products'
 
         # yield 'lino_noi.lib.topics'
-        # yield 'lino_xl.lib.votes'
+        yield 'lino_xl.lib.votes'
         # yield 'lino_xl.lib.stars'
         yield 'lino_noi.lib.tickets'
         # yield 'lino_xl.lib.skills'
@@ -94,15 +95,17 @@ class Site(Site):
         yield 'lino_noi.lib.groups'
 
         yield 'lino_noi.lib.products'
+        yield 'lino_noi.lib.sales'
         yield 'lino_xl.lib.invoicing'
+        yield 'lino_xl.lib.orders'
 
     def get_plugin_configs(self):
         yield super(Site, self).get_plugin_configs()
         yield ('tickets', 'end_user_model', 'contacts.Person')
         yield ('working', 'ticket_model', 'tickets.Ticket')
         yield ('system', 'use_dashboard_layouts', True)
-        # yield ('users', 'use_verify', True)
-
+        yield ('invoicing', 'order_model', 'orders.Order')
+        yield ('users', 'allow_online_registration', True)
 
     # def setup_plugins(self):
     #     super(Site, self).setup_plugins()
@@ -117,11 +120,6 @@ class Site(Site):
     #         ticket_model='tickets.Ticket')
 
 
-    def get_default_required(self, **kw):
-        # overrides the default behaviour which would add
-        # `auth=True`. In Lino Noi everybody can see everything.
-        return kw
-
     # def setup_quicklinks(self, user, tb):
     #     super(Site, self).setup_quicklinks(user, tb)
     #     # tb.add_action(self.models.courses.MyActivities)
@@ -145,6 +143,7 @@ class Site(Site):
 
         wc(self.modules.tickets.Ticket, ignore=['_user_cache'])
         wc(self.modules.comments.Comment, master_key='owner')
+        # wc(self.modules.tickets.Link, master_key='ticket')
         # wc(self.modules.working.Session, master_key='owner')
 
         if self.is_installed('votes'):
