@@ -27,7 +27,7 @@ class Site(Site):
 
     def get_change_observers(self, ar=None):
         action = ar.bound_action.action if ar.bound_action else None
-        if ar is not None and isinstance(action, CreateRow) and issubclass(ar.actor.model,Ticket):
+        if ar is not None and isinstance(action, CreateRow) and issubclass(ar.actor.model.Ticket):
             subs = rt.models.groups.Group.objects.filter(site=ar.selected_rows[-1].site)
             #subs = rt.models.tickets.Subscription.objects.filter(site=ar.selected_rows[-1].site)
             for s in subs.members.all():
