@@ -6,7 +6,7 @@
 
 SETUP_INFO = dict(
     name='lino-noi',
-    version='21.7.0',
+    version='21.9.0',
     install_requires=['lino-xl'],
     # tests_require=['pytest', 'mock'],
     test_suite='tests',
@@ -61,6 +61,8 @@ lino_noi.lib.noi.fixtures
 lino_noi.lib.contacts
 lino_noi.lib.contacts.fixtures
 lino_noi.lib.public
+lino_noi.lib.sales
+lino_noi.lib.sales.fixtures
 lino_noi.lib.topics
 lino_noi.lib.users
 lino_noi.lib.users.fixtures
